==> mule-maven-client-impl-2.1.0-rc1.jar: module-info.java <==
module org.mule.runtime.maven.client.impl {
    requires org.mule.runtime.maven.client.api;
    requires org.mule.runtime.maven.pom.parser.api;
    requires org.mule.runtime.maven.pom.parser.impl;
    requires org.mule.runtime.maven.model.shaded;
    requires java.inject;
    requires jcommander;
    requires maven.builder.support;
    requires maven.resolver.provider;
    requires maven.settings;
    requires maven.settings.builder;
    requires org.apache.commons.lang3;
    requires org.apache.commons.logging;
    requires org.apache.maven.resolver;
    requires org.apache.maven.resolver.impl;
    requires org.apache.maven.resolver.named;
    requires org.apache.maven.resolver.spi;
    requires org.apache.maven.resolver.supplier;
    requires org.apache.maven.resolver.transport.file;
    requires org.apache.maven.resolver.transport.http;
    requires org.apache.maven.resolver.transport.wagon;
    requires org.apache.maven.resolver.util;
    requires org.slf4j;
    requires org.eclipse.sisu.plexus;
    requires org.eclipse.sisu.inject;
    requires plexus.cipher;
    requires plexus.component.annotations;
    requires plexus.sec.dispatcher;
    requires semver4j;
    requires wagon.http;
    requires wagon.http.shared;
    requires wagon.provider.api;

    exports org.mule.maven.client.internal to org.mule.runtime.maven.client.test, org.mule.test.runner;
    exports org.mule.maven.client.internal.util to org.mule.runtime.maven.client.test, org.mule.test.runner;
    exports org.mule.maven.client.internal.wagon to org.mule.runtime.maven.model.shaded;

    opens org.mule.maven.client.internal to jcommander;

    provides MavenClientProvider with MuleMavenClientProvider;
    provides VersionUtils with DefaultVersionUtils;

}

==> mule-maven-client-impl-2.1.22.jar: module-info.java <==
module org.mule.runtime.maven.client.impl {
    requires org.mule.runtime.maven.client.api;
    requires org.mule.runtime.maven.pom.parser.api;
    requires org.mule.runtime.maven.pom.parser.impl;
    requires org.mule.runtime.maven.model.shaded;
    requires java.inject;
    requires jcommander;
    requires maven.builder.support;
    requires maven.resolver.provider;
    requires maven.settings;
    requires maven.settings.builder;
    requires org.apache.commons.logging;
    requires org.apache.maven.resolver;
    requires org.apache.maven.resolver.impl;
    requires org.apache.maven.resolver.named;
    requires org.apache.maven.resolver.spi;
    requires org.apache.maven.resolver.supplier;
    requires org.apache.maven.resolver.transport.file;
    requires org.apache.maven.resolver.transport.http;
    requires org.apache.maven.resolver.transport.wagon;
    requires org.apache.maven.resolver.util;
    requires org.slf4j;
    requires org.eclipse.sisu.plexus;
    requires org.eclipse.sisu.inject;
    requires plexus.cipher;
    requires plexus.component.annotations;
    requires plexus.sec.dispatcher;
    requires semver4j;
    requires wagon.http;
    requires wagon.http.shared;
    requires wagon.provider.api;
    requires org.apache.commons.io;

    exports org.mule.maven.client.internal to org.mule.runtime.maven.client.test, org.mule.test.runner;
    exports org.mule.maven.client.internal.util to org.mule.runtime.maven.client.test, org.mule.test.runner;
    exports org.mule.maven.client.internal.wagon to org.mule.runtime.maven.model.shaded;

    opens org.mule.maven.client.internal to jcommander;

    provides MavenClientProvider with MuleMavenClientProvider;
    provides VersionUtils with DefaultVersionUtils;

}
